@@ -77,6 +77,11 @@ class APIClient:
                 "logger is pointed at the correct address.",
                 url,
             )
+        elif response.status_code == 429:
+            logger.error(
+                "Logger has hit the rate limit. Please reach out to Gantry "
+                "support if you would like to raise this limit."
+            )
         elif response.status_code >= 400 and response.status_code < 500:
             logger.error(
                 "%s Gantry logger error. Ensure the logger is receiving valid data. "
