@@ -1,9 +1,11 @@
 import atexit
+import backoff
 import json
 import logging
 import logging.handlers
+import requests
 from queue import Queue
-from typing import Callable, Collection, Iterator, List, Optional
+from typing import Callable, Collection, Dict, Iterator, List, Optional
 
 from gantry.api_client import APIClient
 from gantry.logger.consumer import BatchConsumer
@@ -13,6 +15,20 @@ from gantry.serializers import EventEncoder
 logger = logging.getLogger(__name__)
 
 
+BATCH_UPLOAD_MAX_TRIES = 3
+
+
+def backoff_retry_handler(backoff_ctx: Dict):
+    logger.warning("Experiencing timeouts. Please check your connection.")
+
+
+def backoff_giveup_handler(backoff_ctx: Dict):
+    logger.error(
+        f"""Failed to log events due to timeout. Have tried {backoff_ctx['tries']}
+         times for {backoff_ctx['elapsed']} seconds. Please check your connection."""
+    )
+
+
 def _batch_iterator_factory(
     collection: Collection, batch_size: int
 ) -> Callable[[], Iterator[List]]:
@@ -50,6 +66,7 @@ class BaseLogStore:
 
 class APILogStore(BaseLogStore):
     BATCH_SIZE = 20
+    BATCH_UPLOAD_TIMEOUT = 20  # seconds before retrying on upload
 
     def __init__(
         self,
@@ -115,7 +132,7 @@ class APILogStore(BaseLogStore):
         the provided API Key.
         """
         try:
-            response = self._api_client.request("GET", "/api/v1/user/me")
+            response = self._api_client.request("GET", "/api/v1/auth-ping")
             check_response(response)
             return True
         except Exception as e:
@@ -130,6 +147,13 @@ class APILogStore(BaseLogStore):
         except Exception as e:
             logger.error("Internal error sending batches: %s", e)
 
+    @backoff.on_exception(
+        backoff.expo,
+        requests.Timeout,
+        max_tries=BATCH_UPLOAD_MAX_TRIES,
+        on_backoff=backoff_retry_handler,
+        on_giveup=backoff_giveup_handler,
+    )
     def send_batch_as_raw_events(self, batch: List, as_raw: bool = False) -> None:
         if as_raw:
             data = b",".join(batch)
@@ -147,6 +171,7 @@ class APILogStore(BaseLogStore):
             data=data,
             params=params,
             headers={"Content-Type": "application/json"},
+            timeout=APILogStore.BATCH_UPLOAD_TIMEOUT,
         )
 
         if response.get("response") != "ok":
