@@ -98,10 +98,10 @@ def get_file_linecount(filepath):
 
 def _build_batch_iterator(iterable, batch_size):
     iterator = iter(iterable)
-    batch = list(islice(iterator, batch_size))
+    batch = islice(iterator, batch_size)
     while batch:
-        line = json.dumps(batch, cls=EventEncoder)
+        lines = "\n".join(map(lambda e: json.dumps(e, cls=EventEncoder), batch))
         batch = list(islice(iterator, batch_size))
         if batch:
-            line += "\n"
-        yield line.encode("utf-8")
+            lines += "\n"
+        yield lines.encode("utf-8")
