@@ -3,6 +3,7 @@ import datetime
 import functools
 import json
 import pprint
+import sys
 from collections import OrderedDict
 from typing import Any, List, NamedTuple, Optional, Union
 
@@ -28,8 +29,12 @@ MAX_WORKERS = 32  # Arbitrary workers for the 'describe' fetching op in datafram
 
 
 @cached(TTLCache(maxsize=MAX_SIZE_CACHE_B, ttl=MAX_TTL_CACHE_SECS))
-def _raw_query_cached_request(api_client: APIClient, dumped_json_data: str):
-    return api_client.request("POST", "/api/v1/aggregate/query", json=json.loads(dumped_json_data))
+def _raw_query_cached_request(
+    api_client: APIClient, dumped_json_data: str, resource: str = "aggregate"
+):
+    return api_client.request(
+        "POST", f"/api/v1/{resource}/query", json=json.loads(dumped_json_data)
+    )
 
 
 class GantryDataFrame(GantryQueryFrame):
@@ -178,7 +183,10 @@ class GantryDataFrame(GantryQueryFrame):
             "to": repr(self.query_info.end_time),
             "series": list(self.series.keys()),
         }
-        return pprint.pformat(info, sort_dicts=False)
+        if (sys.version_info.major, sys.version_info.minor) <= (3, 7):
+            return pprint.pformat(info)  # kwarg sort_dicts not supported
+        else:
+            return pprint.pformat(info, sort_dicts=False)
 
     @property
     def dtypes(self) -> pd.Series:
@@ -502,7 +510,10 @@ class GantrySeries(GantryQueryFrame):
             "type": self.dtype,
             "series_type": self.series_type,
         }
-        return pprint.pformat(info, sort_dicts=False)
+        if (sys.version_info.major, sys.version_info.minor) <= (3, 7):
+            return pprint.pformat(info)  # kwarg sort_dicts not supported
+        else:
+            return pprint.pformat(info, sort_dicts=False)
 
     def __getattr__(self, name: str):
         if name == "dtype":
@@ -556,79 +567,115 @@ class GantrySeries(GantryQueryFrame):
         )
 
     @runs_on("int", "float")
-    def mean(self) -> float:
+    def mean(self, num_points: int = 1) -> Union[float, pd.DataFrame]:
         """
         Runs on numeric series only.
         Get the computed average of this GantrySeries, if available
 
+        Args:
+            num_points (int, defaults to 1): number of points to divide the
+                time window of the GantrySeries into
+
         Returns:
-            float mean
+            Float with mean in case num_points not specified (or num_points=1),
+            else a pd.DataFrame.
         """
         try:
-            return self._aggregate_query("mean")
+            return self._aggregate_query("mean", num_points=num_points)
         except (AttributeError, ValueError, KeyError):
             raise QueryError("Invalid query. GantrySeries cannot determine mean")
 
     @runs_on("int", "float")
-    def std(self) -> float:
+    def std(self, num_points: int = 1) -> Union[float, pd.DataFrame]:
         """
         Runs on numeric series only.
         Get the standard deviation for this GantrySeries, if available
 
+        Args:
+            num_points (int, defaults to 1): number of points to divide the
+                time window of the GantrySeries into
+
         Returns:
-            float standard deviation
+            Float with std in case num_points not specified (or num_points=1),
+            else a pd.DataFrame.
         """
         try:
-            return self._aggregate_query("stddev")
+            return self._aggregate_query("stddev", num_points=num_points)
         except (AttributeError, ValueError, KeyError):
             raise QueryError("Invalid query. GantrySeries cannot determine standard deviation")
 
     @runs_on("int", "float")
-    def median(self) -> float:
+    def median(self, num_points: int = 1) -> Union[float, pd.DataFrame]:
         """
         Runs on numeric series only.
         Get the median for this GantrySeries, if available
 
+        Args:
+            num_points (int, defaults to 1): number of points to divide the
+                time window of the GantrySeries into
+
         Returns:
-            float median
+            Float with median in case num_points not specified (or num_points=1),
+            else a pd.DataFrame.
         """
         try:
-            quantiles = self.quantile([0.5])
+            quantiles = self.quantile([0.5], num_points=num_points)
             return quantiles[0.5]
         except (AttributeError, ValueError, KeyError):
             raise QueryError("Invalid query. GantrySeries cannot determine median")
 
-    def count(self) -> int:
+    def count(self, num_points: int = 1) -> Union[float, pd.DataFrame]:
         """
         Get the number of available data points for this GantrySeries, if available.
 
+        Args:
+            num_points (int, defaults to 1): number of points to divide the
+                time window of the GantrySeries into
+
         Returns:
-            int total count
+            Float with count in case num_points not specified (or num_points=1),
+            else a pd.DataFrame.
         """
         try:
-            return self._aggregate_query("total")
+            return self._aggregate_query("total", num_points=num_points)
         except (AttributeError, ValueError, KeyError):
             raise QueryError("Invalid query. GantrySeries cannot determine count")
 
     @runs_on("int", "float", "datetime")
-    def min(self):
+    def min(self, num_points: int = 1) -> Union[float, datetime.datetime, pd.DataFrame]:
         """
         Runs on numeric and datetime series only.
         Get the minimum for this GantrySeries, if available.
+
+        Args:
+            num_points (int, defaults to 1): number of points to divide the
+                time window of the GantrySeries into
+
+        Returns:
+            Float with min value in case num_points not specified (or num_points=1),
+            else a pd.DataFrame.
         """
         try:
-            return self._aggregate_query("minimum")
+            return self._aggregate_query("minimum", num_points=num_points)
         except (AttributeError, ValueError, KeyError):
             raise QueryError("Invalid query. GantrySeries cannot determine min")
 
     @runs_on("int", "float", "datetime")
-    def max(self):
+    def max(self, num_points: int = 1) -> Union[float, datetime.datetime, pd.DataFrame]:
         """
         Runs on numeric and datetime series only.
         Get the maximum for this GantrySeries, if available.
+
+        Args:
+            num_points (int, defaults to 1): number of points to divide the
+                time window of the GantrySeries into
+
+        Returns:
+            Float with max value in case num_points not specified (or num_points=1),
+            else a pd.DataFrame.
         """
         try:
-            return self._aggregate_query("maximum")
+            return self._aggregate_query("maximum", num_points=num_points)
         except (AttributeError, ValueError, KeyError):
             raise QueryError("Invalid query. GantrySeries cannot determine max")
 
@@ -661,7 +708,7 @@ class GantrySeries(GantryQueryFrame):
                 quantile_vals order.
         """
         try:
-            quantile_res = self._aggregate_query("quantiles", {"quantile_vals": quantile_vals})
+            quantile_res = self._aggregate_query("quantiles", quantile_vals=quantile_vals)
             return {float(k): v for k, v in quantile_res.items()}
         except (AttributeError, ValueError, KeyError):
             raise QueryError("Invalid query. GantrySeries cannot determine quantiles")
@@ -689,8 +736,11 @@ class GantrySeries(GantryQueryFrame):
     def _dtype(self):
         return self.datatype
 
-    def _aggregate_query(self, attribute, attribute_kwargs={}):
+    def _aggregate_query(self, attribute, num_points: int = 1, **attribute_kwargs):
         data = self.query_info.get_base_query_params()
+        if num_points <= 0:
+            raise ValueError(f"num_points must be an int > 0, but received value of {num_points}")
+        data["num_points"] = num_points
         data["queries"] = {
             "query": {
                 "query_type": "feature",
@@ -702,12 +752,19 @@ class GantrySeries(GantryQueryFrame):
                 "tags": self.parent_dataframe.tags,
             }
         }
+        resource = "aggregate" if num_points == 1 else "time_series"
         response = _raw_query_cached_request(
-            self.api_client, json.dumps(data, default=lambda x: x.isoformat())
+            self.api_client, json.dumps(data, default=lambda x: x.isoformat()), resource=resource
         )
         try:
             check_response(response)
-            return response["data"]["query"][attribute]
+            data = response["data"]["query"]
+
+            if num_points == 1:
+                return data[attribute]
+            else:
+                return pd.DataFrame(data["points"])
+
         except GantryException as e:
             raise GantryException(
                 "Aggregation query [" + attribute + "] failed on API with this error: " + str(e)
@@ -762,3 +819,60 @@ class GantrySeries(GantryQueryFrame):
             index=["application", "from", "to", *stats.keys()],
             columns=[self.name],
         )
+
+    @runs_on("bool")
+    def percent_true(self, dropna: bool = False, num_points: int = 1):
+        """
+        Percent true
+
+        Args:
+            data_node (GantrySeries): GantrySeries which will be calculated
+            dropna (bool, defaults to False): if True, first drops NaN values
+                before calculating result.
+            num_points (int, defaults to 1): number of points to divide the
+                time window of the GantrySeries into
+
+        Returns:
+            (pd.DataFrame) pd.DataFrame of shape (num_points, 1) percent true
+        """
+        from gantry.query.metric.main import percent_true
+
+        return percent_true(self, dropna, num_points)
+
+    @runs_on("bool")
+    def percent_false(self, dropna: bool = False, num_points: int = 1):
+        """
+        Percent false
+
+        Args:
+            data_node (GantrySeries): GantrySeries which will be calculated
+            dropna (bool, defaults to False): if True, first drops NaN values
+                before calculating result.
+            num_points (int, defaults to 1): number of points to divide the
+                time window of the GantrySeries into
+
+        Returns:
+            (pd.DataFrame) pd.DataFrame of shape (num_points, 1) percent false
+        """
+        from gantry.query.metric.main import percent_false
+
+        return percent_false(self, dropna, num_points)
+
+    @runs_on("bool")
+    def percent_null(self, num_points: int = 1):
+        """
+        Percent null/NaN
+
+        Args:
+            data_node (GantrySeries): GantrySeries which will be calculated
+            dropna (bool, defaults to False): if True, drop rows with NaN
+                values in result.
+            num_points (int, defaults to 1): number of points to divide the
+                time window of the GantrySeries into
+
+        Returns:
+            (pd.DataFrame) pd.DataFrame of shape (num_points, 1) percent_null
+        """
+        from gantry.query.metric.main import percent_null
+
+        return percent_null(self, num_points=num_points)
