@@ -1,4 +1,5 @@
 import functools
+import warnings
 from typing import Dict, List
 
 try:
@@ -12,6 +13,23 @@ from gantry.query.core.dataframe import GantrySeries
 from gantry.query.core.utils import check_response, same_size
 
 
+def _prepare_pandas_dataframe(stat, results, dropna) -> pd.DataFrame:
+    df = pd.DataFrame.from_records(results)
+    if df.empty:
+        return df
+
+    # note that if num_points is 1, the timestamp is start_time
+    # this is probably better than using end_time because
+    # end_time is possibly in the future
+    df.time_stamp = pd.to_datetime(df.time_stamp)
+    df.rename(columns={"value": stat, "time_stamp": "timestamp"}, inplace=True)
+
+    if dropna:
+        df = df.dropna()
+
+    return df.set_index("timestamp")
+
+
 def categorical(func):
     @functools.wraps(func)
     def categorical_dec(self, outputs: GantrySeries, feedback: GantrySeries, *args, **kwargs):
@@ -124,22 +142,6 @@ class GantryMetric(object):
         check_response(response)
         return response["data"]["query_label"].get("points", [])
 
-    def _prepare_pandas_dataframe(self, stat, results, dropna) -> pd.DataFrame:
-        df = pd.DataFrame.from_records(results)
-        if df.empty:
-            return df
-
-        # note that if num_points is 1, the timestamp is start_time
-        # this is probably better than using end_time because
-        # end_time is possibly in the future
-        df.time_stamp = pd.to_datetime(df.time_stamp)
-        df.rename(columns={"value": stat, "time_stamp": "timestamp"}, inplace=True)
-
-        if dropna:
-            df = df.dropna()
-
-        return df.set_index("timestamp")
-
     @categorical
     @same_size("outputs", "feedback")
     def accuracy_score(
@@ -156,11 +158,16 @@ class GantryMetric(object):
         the available |feedback|.
 
         Args:
-            outputs: predictions as a GantrySeries
-            feedback: labels to compare against as a GantrySeries
-            dropna: if True, drop rows with NaN values in result
-            num_points: number of points to divide the time window of the GantrySeries into
-        Returns: pd.DataFrame of shape (num_points, 1) accuracy score
+            outputs (GantrySeries): predictions as a GantrySeries
+            feedback (GantrySeries): labels to compare against as
+                a GantrySeries
+            dropna (bool, defaults to False): if True, drop rows with NaN
+                values in result
+            num_points (int, defaults to 1): number of points to divide the
+                time window of the GantrySeries into
+
+        Returns:
+            (pd.DataFrame) pd.DataFrame of shape (num_points, 1) accuracy score
         """
         stat = "accuracy_score"
         results = self._metric_query(
@@ -168,7 +175,7 @@ class GantryMetric(object):
             stat,
             num_points=num_points,
         )
-        return self._prepare_pandas_dataframe(stat, results, dropna=dropna)
+        return _prepare_pandas_dataframe(stat, results, dropna=dropna)
 
     @regression
     @same_size("outputs", "feedback")
@@ -183,15 +190,20 @@ class GantryMetric(object):
     ) -> pd.DataFrame:
         """
         Regression metric- mean squared error
+
         Args:
-            outputs: predictions as a GantrySeries
-            feedback: labels to compare against as a GantrySeries
-            dropna: if True, drop rows with NaN values in result
-            num_points: number of points to divide the time window of the GantrySeries into
-            multioutput: type of averaging to use when computing the metric
-                Can be one of "uniform_average", "raw_values"
-            squared: if True, return the squared error
-        Returns: pd.DataFrame of shape (num_points, 1) mean_squared_error
+            outputs (GantrySeries): predictions as a GantrySeries
+            feedback (GantrySeries): labels to compare against as a GantrySeries
+            dropna (bool, defaults to False): if True, drop rows with NaN values in result
+            num_points (int, defaults to 1): number of points to divide the
+                time window of the GantrySeries into.
+            multioutput ("uniform_average" or "raw_values"): type of
+                averaging to use when computing the metric. Defaults to
+                "uniform_average".
+            squared (boo, defaults to True): if True, return the squared error.
+
+        Returns:
+            (pd.DataFrame) pd.DataFrame of shape (num_points, 1) mean_squared_error
         """
         stat = "mean_squared_error"
         results = self._metric_query(
@@ -200,7 +212,7 @@ class GantryMetric(object):
             num_points=num_points,
             stat_kwargs={"multioutput": multioutput, "squared": squared},
         )
-        return self._prepare_pandas_dataframe(stat, results, dropna=dropna)
+        return _prepare_pandas_dataframe(stat, results, dropna=dropna)
 
     @categorical
     @same_size("outputs", "feedback")
@@ -216,12 +228,19 @@ class GantryMetric(object):
         The confusion matrix is a matrix :math:`C` where :math:`C_{i, j}`
         represents the number of times a data point from the class :math:`i`
         was predicted to be in class :math:`j`.
+
         Args:
-            outputs: predictions as a GantrySeries
-            feedback: labels to compare against as a GantrySeries
-            dropna: if True, drop rows with NaN values in result
-            num_points: number of points to divide the time window of the GantrySeries into
-        Returns: pd.DataFrame of shape (num_points, 1) confusion_matrix
+            outputs (GantrySeries): predictions as a GantrySeries
+            feedback (GantrySeries): labels to compare against as a
+                GantrySeries.
+            dropna (bool, defaults to False): if True, drop rows with NaN
+                values in result.
+            num_points (int, defaults to 1): number of points to divide the
+                time window of the GantrySeries into
+
+        Returns:
+            (pd.DataFrame) pd.DataFrame of shape (num_points, 1)
+                confusion_matrix
         """
         stat = "confusion_matrix"
         results = self._metric_query(
@@ -229,7 +248,7 @@ class GantryMetric(object):
             stat,
             num_points=num_points,
         )
-        return self._prepare_pandas_dataframe(stat, results, dropna=dropna)
+        return _prepare_pandas_dataframe(stat, results, dropna=dropna)
 
     @categorical
     @same_size("outputs", "feedback")
@@ -249,12 +268,19 @@ class GantryMetric(object):
         In multiclass classification, this is the average of the F1 score for all available classes.
 
         Args:
-            outputs: predictions as a GantrySeries
-            feedback: labels to compare against as a GantrySeries
-            dropna: if True, drop rows with NaN values in result
-            num_points: number of points to divide the time window of the GantrySeries into
-            average: type of averaging to use when computing the metric
-        Returns: pd.DataFrame of shape (num_points, 1) f1_score
+            outputs (GantrySeries): predictions as a GantrySeries
+            feedback (GantrySeries): labels to compare against as a
+                GantrySeries.
+            dropna (bool, defaults to False): if True, drop rows with NaN
+                values in result.
+            num_points (int, defaults to 1): number of points to divide the
+                time window of the GantrySeries into
+            average ("micro"): type of averaging to use when computing
+                the metric. Currently only "micro" supported, which is
+                the default value.
+
+        Returns:
+            (pd.DataFrame) pd.DataFrame of shape (num_points, 1) f1_score
         """
         stat = "f1_score"
         results = self._metric_query(
@@ -263,7 +289,7 @@ class GantryMetric(object):
             num_points=num_points,
             stat_kwargs={"average": average},
         )
-        return self._prepare_pandas_dataframe(stat, results, dropna=dropna)
+        return _prepare_pandas_dataframe(stat, results, dropna=dropna)
 
     @regression
     @same_size("outputs", "feedback")
@@ -279,14 +305,21 @@ class GantryMetric(object):
     ) -> float:
         """
         Regression metric- R^2 coefficient of determination
+
         Args:
-            outputs: predictions as a GantrySeries
-            feedback: labels to compare against as a GantrySeries
-            dropna: if True, drop rows with NaN values in result
-            num_points: number of points to divide the time window of the GantrySeries into
-            multioutput: type of averaging to use when computing the metric
+            outputs (GantrySeries): predictions as a GantrySeries
+            feedback (GantrySeries): labels to compare against as a
+                GantrySeries.
+            dropna (bool, defaults to False): if True, drop rows with NaN
+                values in result.
+            num_points (int, defaults to 1): number of points to divide the
+                time window of the GantrySeries into
+            multioutput ("uniform_average", "raw_values", "variance_weighted"):
+                type of averaging to use when computing the metric. Defaults
+                to "uniform_average".
+
         Returns:
-            float R^2 score.
+            (float) R^2 score.
         """
         stat = "r2_score"
         results = self._metric_query(
@@ -295,7 +328,7 @@ class GantryMetric(object):
             num_points=num_points,
             stat_kwargs={"multioutput": multioutput},
         )
-        return self._prepare_pandas_dataframe(stat, results, dropna=dropna)
+        return _prepare_pandas_dataframe(stat, results, dropna=dropna)
 
     @categorical
     @same_size("outputs", "feedback")
@@ -309,15 +342,24 @@ class GantryMetric(object):
     ) -> pd.DataFrame:
         """
         Categorical metric - precision score
+
         precision =
         (number of true positives) / ((number of true positives) + (number of false positives))
+
         Args:
-            outputs: predictions as a GantrySeries
-            feedback: labels to compare against as a GantrySeries
-            dropna: if True, drop rows with NaN values in result
-            num_points: number of points to divide the time window of the GantrySeries into
-            average: type of averaging to use when computing the metric
-        Returns: pd.DataFrame of shape (num_points, 1) precision_score
+            outputs (GantrySeries): predictions as a GantrySeries
+            feedback (GantrySeries): labels to compare against as a
+                GantrySeries.
+            dropna (bool, defaults to False): if True, drop rows with NaN
+                values in result.
+            num_points (int, defaults to 1): number of points to divide the
+                time window of the GantrySeries into
+            average ("micro"): type of averaging to use when computing
+                the metric. Currently only "micro" supported, which is
+                the default value.
+
+        Returns:
+            (pd.DataFrame) pd.DataFrame of shape (num_points, 1) precision_score
         """
         stat = "precision_score"
         results = self._metric_query(
@@ -326,7 +368,7 @@ class GantryMetric(object):
             num_points=num_points,
             stat_kwargs={"average": average},
         )
-        return self._prepare_pandas_dataframe(stat, results, dropna=dropna)
+        return _prepare_pandas_dataframe(stat, results, dropna=dropna)
 
     @categorical
     @same_size("outputs", "feedback")
@@ -340,15 +382,24 @@ class GantryMetric(object):
     ) -> pd.DataFrame:
         """
         Categorical metric - recall score
+
         recall =
         (number of true positives) / ((number of true positives) + (number of false negatives))
+
         Args:
-            outputs: predictions as a GantrySeries
-            feedback: labels to compare against as a GantrySeries
-            dropna: if True, drop rows with NaN values in result
-            num_points: number of points to divide the time window of the GantrySeries into
-            average: type of averaging to use when computing the metric
-        Returns: pd.DataFrame of shape (num_points, 1) recall_score
+            outputs (GantrySeries): predictions as a GantrySeries
+            feedback (GantrySeries): labels to compare against as a
+                GantrySeries.
+            dropna (bool, defaults to False): if True, drop rows with NaN
+                values in result.
+            num_points (int, defaults to 1): number of points to divide the
+                time window of the GantrySeries into
+            average ("micro"): type of averaging to use when computing
+                the metric. Currently only "micro" supported, which is
+                the default value.
+
+        Returns:
+            (pd.DataFrame) pd.DataFrame of shape (num_points, 1) recall_score
         """
         stat = "recall_score"
         results = self._metric_query(
@@ -357,7 +408,7 @@ class GantryMetric(object):
             num_points=num_points,
             stat_kwargs={"average": average},
         )
-        return self._prepare_pandas_dataframe(stat, results, dropna=dropna)
+        return _prepare_pandas_dataframe(stat, results, dropna=dropna)
 
     @score
     @same_size("outputs", "feedback")
@@ -370,12 +421,18 @@ class GantryMetric(object):
     ) -> pd.DataFrame:
         """
         Classification score metric - the area under the ROC curve
+
         Args:
-            outputs: predictions as GantrySeries
-            feedback: labels to compare against as a GantrySerires
-            dropna: if True, drop rows with NaN values in result
-            num_points: number of points to divide the time window of the GantrySeries into
-        Returns: pd.DataFrame of shape (num_points, 1) roc_auc_score
+            outputs (GantrySeries): predictions as a GantrySeries
+            feedback (GantrySeries): labels to compare against as a
+                GantrySeries.
+            dropna (bool, defaults to False): if True, drop rows with NaN
+                values in result.
+            num_points (int, defaults to 1): number of points to divide the
+                time window of the GantrySeries into
+
+        Returns:
+            (pd.DataFrame) pd.DataFrame of shape (num_points, 1) roc_auc_score
         """
         stat = "roc_auc_score"
         results = self._metric_query(
@@ -383,7 +440,7 @@ class GantryMetric(object):
             stat,
             num_points=num_points,
         )
-        return self._prepare_pandas_dataframe(stat, results, dropna=dropna)
+        return _prepare_pandas_dataframe(stat, results, dropna=dropna)
 
     def _percent_query(
         self,
@@ -392,21 +449,15 @@ class GantryMetric(object):
         dropna: bool = False,
         num_points: int = 1,
     ) -> pd.DataFrame:
-        """
-        Percent query
-        Args:
-            stat: query type
-            data_node: GantrySeries which will be cacluated
-            dropna: if True, drop rows with NaN values in result
-            num_points: number of points to divide the time window of the GantrySeries into
-        Returns: pd.DataFrame of shape (num_points, 1)
-        """
+        if dropna:
+            data_node = data_node[data_node.notna()]  # type: ignore
+
         results = self._metric_query(
             [data_node],
             stat,
             num_points=num_points,
         )
-        return self._prepare_pandas_dataframe(stat, results, dropna=dropna)
+        return _prepare_pandas_dataframe(stat, results, dropna=False)
 
     def percent_null(
         self,
@@ -416,14 +467,26 @@ class GantryMetric(object):
     ) -> pd.DataFrame:
         """
         Percent null/NaN
+
         Args:
-            data_node: GantrySeries which will be cacluated
-            dropna: if True, drop rows with NaN values in result
-            num_points: number of points to divide the time window of the GantrySeries into
-        Returns: pd.DataFrame of shape (num_points, 1) percent_null
+            data_node (GantrySeries): GantrySeries which will be calculated
+            dropna (bool, defaults to False): if True, drop rows with NaN
+                values in result.
+            num_points (int, defaults to 1): number of points to divide the
+                time window of the GantrySeries into
+
+        Returns:
+            (pd.DataFrame) pd.DataFrame of shape (num_points, 1) percent_null
         """
+        if dropna:
+            warnings.warn(
+                "'dropna' parameter is no longer valid in this "
+                "query as it was a bug. Please remove it as it "
+                "will be removed in future versions"
+            )
+
         stat = "percent_null"
-        return self._percent_query(stat, data_node, dropna, num_points)
+        return self._percent_query(stat, data_node, False, num_points)
 
     @bool_type_check
     def percent_true(
@@ -434,11 +497,16 @@ class GantryMetric(object):
     ) -> pd.DataFrame:
         """
         Percent true
+
         Args:
-            data_node: GantrySeries which will be cacluated
-            dropna: if True, drop rows with NaN values in result
-            num_points: number of points to divide the time window of the GantrySeries into
-        Returns: pd.DataFrame of shape (num_points, 1) percent_true
+            data_node (GantrySeries): GantrySeries which will be calculated
+            dropna (bool, defaults to False): if True, first drops NaN values
+                before calculating result.
+            num_points (int, defaults to 1): number of points to divide the
+                time window of the GantrySeries into
+
+        Returns:
+            (pd.DataFrame) pd.DataFrame of shape (num_points, 1) percent_true
         """
         stat = "percent_true"
         return self._percent_query(stat, data_node, dropna, num_points)
@@ -452,11 +520,16 @@ class GantryMetric(object):
     ) -> pd.DataFrame:
         """
         Percent false
+
         Args:
-            data_node: GantrySeries which will be cacluated
-            dropna: if True, drop rows with NaN values in result
-            num_points: number of points to divide the time window of the GantrySeries into
-        Returns: pd.DataFrame of shape (num_points, 1) percent_false
+            data_node (GantrySeries): GantrySeries which will be calculated
+            dropna (bool, defaults to False): if True, first drops NaN values
+                before calculating result.
+            num_points (int, defaults to 1): number of points to divide the
+                time window of the GantrySeries into
+
+        Returns:
+            (pd.DataFrame) pd.DataFrame of shape (num_points, 1) percent_false
         """
         stat = "percent_false"
         return self._percent_query(stat, data_node, dropna, num_points)
