@@ -1,10 +1,11 @@
 import functools
 from datetime import datetime
 from inspect import getcallargs, getfullargspec
-from typing import Optional, Tuple, Union, cast
+from typing import Dict, Optional, Tuple, Union, cast
 
 import dateparser
 import isodate
+import pandas as pd
 
 from gantry.api_client import APIClient
 from gantry.exceptions import GantryException
@@ -147,3 +148,14 @@ def get_start_end_time_from_view(view: dict) -> Tuple[datetime, datetime]:
         )
 
     return start_time, end_time
+
+
+def _build_empty_df_with_schema(schema: Dict[str, str]) -> pd.DataFrame:
+    cols = [item[0] for item in schema.items()]
+    ret = pd.DataFrame(columns=cols)
+    for col, dtype in schema.items():
+        try:
+            ret[col] = ret[col].astype(dtype)
+        except TypeError:
+            ret[col] = ret[col].astype("str")
+    return ret
