@@ -1698,7 +1698,7 @@ def test_log_predictions_as_batch(
     with responses.RequestsMock() as resp:
         resp.add(
             resp.GET,
-            f"{HOST}/api/v1/ingest/file-preupload?filename=simple_test_{size}&num_parts=1&filetype=EVENTS_BYTES",  # noqa
+            f"{HOST}/api/v1/ingest/file-preupload?filename=simple_test_{size}&num_parts=1&filetype=EVENTS",  # noqa
             json={
                 "response": "ok",
                 "upload_urls": ["http://test_url"],
@@ -1761,7 +1761,7 @@ def test_log_feedback_as_batch(
     with responses.RequestsMock() as resp:
         resp.add(
             resp.GET,
-            f"{HOST}/api/v1/ingest/file-preupload?filename=simple_test_{size}&num_parts=1&filetype=EVENTS_BYTES",  # noqa
+            f"{HOST}/api/v1/ingest/file-preupload?filename=simple_test_{size}&num_parts=1&filetype=EVENTS",  # noqa
             json={
                 "response": "ok",
                 "upload_urls": ["http://test_url"],
@@ -1815,7 +1815,7 @@ def test_batch_completion_fail(mock_uuid, init_gantry_with_api):
     with responses.RequestsMock() as resp:
         resp.add(
             resp.GET,
-            f"{HOST}/api/v1/ingest/file-preupload?filename=simple_test_{size}&num_parts=1&filetype=EVENTS_BYTES",  # noqa
+            f"{HOST}/api/v1/ingest/file-preupload?filename=simple_test_{size}&num_parts=1&filetype=EVENTS",  # noqa
             json={
                 "response": "ok",
                 "upload_urls": ["http://test_url"],
@@ -1851,7 +1851,7 @@ def test_batch_preupload_fail(mock_uuid, init_gantry_with_api):
     with responses.RequestsMock() as resp:
         resp.add(
             resp.GET,
-            f"{HOST}/api/v1/ingest/file-preupload?filename=simple_test_{size}&num_parts=1&filetype=EVENTS_BYTES",  # noqa
+            f"{HOST}/api/v1/ingest/file-preupload?filename=simple_test_{size}&num_parts=1&filetype=EVENTS",  # noqa
             json={"response": "broken-return"},
         )
 
@@ -2130,7 +2130,7 @@ def test__upload_data_as_batch(
         DataLink(
             application="test_app",
             version=str(version) if version is not None else version,
-            file_type=UploadFileType.EVENTS_BYTES,
+            file_type=UploadFileType.EVENTS,
             batch_type=BatchType.RECORD,
             log_timestamp=CURRENT_TIME.isoformat(),
             num_events=2,
