@@ -23,11 +23,12 @@ def test_series_filters_property_getter(series_obj_factory, api_client_obj, quer
     assert series_obj.filters == filters
 
 
+@pytest.mark.parametrize("num_points_kwargs", [{}, {"num_points": 1}, {"num_points": 10}])
 @mock.patch("gantry.query.core.dataframe.GantrySeries._aggregate_query")
-def test_mean(mock_query, series_obj):
+def test_mean(mock_query, num_points_kwargs, series_obj):
     mock_query.return_value = 0.5
-    assert series_obj.mean() == 0.5
-    mock_query.assert_called_once_with("mean")
+    assert series_obj.mean(**num_points_kwargs) == 0.5
+    mock_query.assert_called_once_with("mean", num_points=num_points_kwargs.get("num_points", 1))
 
 
 @pytest.mark.parametrize("error", [AttributeError, ValueError, KeyError])
@@ -36,14 +37,15 @@ def test_mean_error(mock_query, error, series_obj):
     mock_query.side_effect = error
     with pytest.raises(QueryError):
         series_obj.mean()
-    mock_query.assert_called_once_with("mean")
+    mock_query.assert_called_once_with("mean", num_points=1)
 
 
+@pytest.mark.parametrize("num_points_kwargs", [{}, {"num_points": 1}, {"num_points": 10}])
 @mock.patch("gantry.query.core.dataframe.GantrySeries._aggregate_query")
-def test_std(mock_query, series_obj):
+def test_std(mock_query, num_points_kwargs, series_obj):
     mock_query.return_value = 0.6
-    assert series_obj.std() == 0.6
-    mock_query.assert_called_once_with("stddev")
+    assert series_obj.std(**num_points_kwargs) == 0.6
+    mock_query.assert_called_once_with("stddev", num_points=num_points_kwargs.get("num_points", 1))
 
 
 @pytest.mark.parametrize("error", [AttributeError, ValueError, KeyError])
@@ -52,14 +54,15 @@ def test_std_error(mock_query, error, series_obj):
     mock_query.side_effect = error
     with pytest.raises(QueryError):
         series_obj.std()
-    mock_query.assert_called_once_with("stddev")
+    mock_query.assert_called_once_with("stddev", num_points=1)
 
 
+@pytest.mark.parametrize("num_points_kwargs", [{}, {"num_points": 1}, {"num_points": 10}])
 @mock.patch("gantry.query.core.dataframe.GantrySeries.quantile")
-def test_median(mock_query, series_obj):
+def test_median(mock_query, num_points_kwargs, series_obj):
     mock_query.return_value = {0.5: 0.7}
-    assert series_obj.median() == 0.7
-    mock_query.assert_called_once_with([0.5])
+    assert series_obj.median(**num_points_kwargs) == 0.7
+    mock_query.assert_called_once_with([0.5], num_points=num_points_kwargs.get("num_points", 1))
 
 
 @pytest.mark.parametrize("error", [AttributeError, ValueError, KeyError])
@@ -68,21 +71,22 @@ def test_median_error(mock_query, error, series_obj):
     mock_query.side_effect = error
     with pytest.raises(QueryError):
         series_obj.median()
-    mock_query.assert_called_once_with([0.5])
+    mock_query.assert_called_once_with([0.5], num_points=1)
 
 
+@pytest.mark.parametrize("num_points_kwargs", [{}, {"num_points": 1}, {"num_points": 10}])
 @mock.patch("gantry.query.core.dataframe.GantrySeries._aggregate_query")
-def test_count(mock_query, series_obj):
+def test_count(mock_query, num_points_kwargs, series_obj):
     mock_query.return_value = 100
-    assert series_obj.count() == 100
-    mock_query.assert_called_once_with("total")
+    assert series_obj.count(**num_points_kwargs) == 100
+    mock_query.assert_called_once_with("total", num_points=num_points_kwargs.get("num_points", 1))
 
 
 @mock.patch("gantry.query.core.dataframe.GantrySeries._aggregate_query")
 def test_len(mock_query, series_obj):
     mock_query.return_value = 100
     assert len(series_obj) == 100
-    mock_query.assert_called_once_with("total")
+    mock_query.assert_called_once_with("total", num_points=1)
 
 
 @pytest.mark.parametrize("error", [AttributeError, ValueError, KeyError])
@@ -91,16 +95,17 @@ def test_count_error(mock_query, error, series_obj):
     mock_query.side_effect = error
     with pytest.raises(QueryError):
         series_obj.count()
-    mock_query.assert_called_once_with("total")
+    mock_query.assert_called_once_with("total", num_points=1)
 
 
+@pytest.mark.parametrize("num_points_kwargs", [{}, {"num_points": 1}, {"num_points": 10}])
 @pytest.mark.parametrize("datatype", ["int", "float"])
 @mock.patch("gantry.query.core.dataframe.GantrySeries._aggregate_query")
-def test_min(mock_query, datatype, series_obj_factory):
+def test_min(mock_query, datatype, num_points_kwargs, series_obj_factory):
     series_obj = series_obj_factory(datatype)
     mock_query.return_value = 1
-    assert series_obj.min() == 1
-    mock_query.assert_called_once_with("minimum")
+    assert series_obj.min(**num_points_kwargs) == 1
+    mock_query.assert_called_once_with("minimum", num_points=num_points_kwargs.get("num_points", 1))
 
 
 @pytest.mark.parametrize("invalid_datatype", ["str", "bool", "category"])
@@ -116,16 +121,17 @@ def test_min_error(mock_query, error, series_obj):
     mock_query.side_effect = error
     with pytest.raises(QueryError):
         series_obj.min()
-    mock_query.assert_called_once_with("minimum")
+    mock_query.assert_called_once_with("minimum", num_points=1)
 
 
+@pytest.mark.parametrize("num_points_kwargs", [{}, {"num_points": 1}, {"num_points": 10}])
 @pytest.mark.parametrize("datatype", ["int", "float"])
 @mock.patch("gantry.query.core.dataframe.GantrySeries._aggregate_query")
-def test_max(mock_query, datatype, series_obj_factory):
+def test_max(mock_query, datatype, num_points_kwargs, series_obj_factory):
     series_obj = series_obj_factory(datatype)
     mock_query.return_value = 1000
-    assert series_obj.max() == 1000
-    mock_query.assert_called_once_with("maximum")
+    assert series_obj.max(**num_points_kwargs) == 1000
+    mock_query.assert_called_once_with("maximum", num_points=num_points_kwargs.get("num_points", 1))
 
 
 @pytest.mark.parametrize("invalid_datatype", ["str", "bool", "category"])
@@ -141,7 +147,7 @@ def test_max_error(mock_query, error, series_obj):
     mock_query.side_effect = error
     with pytest.raises(QueryError):
         series_obj.max()
-    mock_query.assert_called_once_with("maximum")
+    mock_query.assert_called_once_with("maximum", num_points=1)
 
 
 @mock.patch("gantry.query.core.dataframe.GantrySeries._aggregate_query")
@@ -165,7 +171,7 @@ def test_histogram_error(mock_query, error, series_obj):
 def test_quantile(mock_query, vals, series_obj):
     mock_query.return_value = {1: 10}
     assert series_obj.quantile(vals) == {1.0: 10}
-    mock_query.assert_called_once_with("quantiles", {"quantile_vals": vals})
+    mock_query.assert_called_once_with("quantiles", quantile_vals=vals)
 
 
 @pytest.mark.parametrize("error", [AttributeError, ValueError, KeyError])
@@ -221,6 +227,7 @@ def test_aggregate_query(mock_query_data, series_obj_factory_with_filters_and_ta
             "start_time": "2008-09-03T20:56:35",
             "end_time": "2008-09-10T23:58:23",
             "version": "1.2.3",
+            "num_points": 1,
             "queries": {
                 "query": {
                     "query_type": "feature",
@@ -238,8 +245,47 @@ def test_aggregate_query(mock_query_data, series_obj_factory_with_filters_and_ta
     series_obj = series_obj_factory_with_filters_and_tags("int", filters=filters, tags=tags)
     mock_query_data.return_value = {"response": "ok", "data": {"query": {"some-attribute": 10}}}
 
-    assert series_obj._aggregate_query("some-attribute", {"a": 10}) == 10
-    mock_query_data.assert_called_with(series_obj.api_client, content)
+    assert series_obj._aggregate_query("some-attribute", a=10) == 10
+    mock_query_data.assert_called_with(series_obj.api_client, content, resource="aggregate")
+
+
+@pytest.mark.parametrize("num_points", [2, 5, 10])
+@pytest.mark.parametrize("tags", [{}, {"foo": "bar"}])
+@pytest.mark.parametrize("filters", [[], [{"some": "filter"}]])
+@mock.patch("gantry.query.core.dataframe._raw_query_cached_request")
+def test_aggregate_query_num_points(
+    mock_query_data, series_obj_factory_with_filters_and_tags, filters, tags, num_points
+):
+    content = json.dumps(
+        {
+            "start_time": "2008-09-03T20:56:35",
+            "end_time": "2008-09-10T23:58:23",
+            "version": "1.2.3",
+            "num_points": num_points,
+            "queries": {
+                "query": {
+                    "query_type": "feature",
+                    "model_node_id": "ABCD1234",
+                    "stat": "some-attribute",
+                    "stat_kwargs": {"some-attribute": {"a": 10}},
+                    "feature": "series_name",
+                    "filters": filters,
+                    "tags": tags,
+                }
+            },
+        },
+        default=lambda x: x.isoformat(),
+    )
+    series_obj = series_obj_factory_with_filters_and_tags("int", filters=filters, tags=tags)
+    mock_query_data.return_value = {
+        "response": "ok",
+        "data": {"query": {"points": [{"A": 10, "B": 10}, {"A": 20, "B": 20}]}},
+    }
+
+    res = series_obj._aggregate_query("some-attribute", num_points=num_points, a=10)
+    assert_frame_equal(res, pd.DataFrame([{"A": 10, "B": 10}, {"A": 20, "B": 20}]))
+
+    mock_query_data.assert_called_with(series_obj.api_client, content, resource="time_series")
 
 
 @pytest.mark.parametrize("tags", [{}, {"foo": "bar"}])
@@ -255,10 +301,19 @@ def test_aggregate_query_error(
         GantryException,
         match=r"Aggregation query \[some-attribute\] failed on API with this error: Request failed",
     ):
-        _ = series_obj._aggregate_query("some-attribute", {"a": 10})
+        _ = series_obj._aggregate_query("some-attribute", a=10)
 
 
-def test_raw_query_cached_request(api_client_obj):
+@pytest.mark.parametrize("invalid_num_points", [0, -1, -100])
+def test_aggregate_query_error_num_points(invalid_num_points, series_obj_factory):
+    series_obj = series_obj_factory("int")
+    with pytest.raises(
+        ValueError,
+    ):
+        _ = series_obj._aggregate_query("some-attribute", num_points=invalid_num_points, a=10)
+
+
+def test_raw_query_cached_request_default_resource(api_client_obj):
     with responses.RequestsMock() as rsps:
         rsps.add(
             responses.POST,
@@ -272,6 +327,22 @@ def test_raw_query_cached_request(api_client_obj):
         }
 
 
+def test_raw_query_cached_request_provided_resource(api_client_obj):
+    with responses.RequestsMock() as rsps:
+        rsps.add(
+            responses.POST,
+            "{}/api/v1/foobar/query".format(ORIGIN),
+            json={"response": "ok", "data": "100"},
+            match=[matchers.json_params_matcher({"foo": "bar"})],
+        )
+        assert dataframe._raw_query_cached_request(
+            api_client_obj, '{"foo": "bar"}', resource="foobar"
+        ) == {
+            "response": "ok",
+            "data": "100",
+        }
+
+
 @pytest.mark.parametrize("op", ["__eq__", "__gt__", "__lt__", "__ge__", "__le__"])
 @pytest.mark.parametrize("invalid_filter", [[1, 2, 3], {"foo": "bar"}, object()])
 def test_comparator_invalid_filter(invalid_filter, op, series_obj):
