@@ -50,13 +50,13 @@ def test_list_applications(data, expected, gantry_query_obj):
 @pytest.mark.parametrize(
     ["versions", "expected"],
     [
-        ([{"internal_version": 10, "version": "baz"}], [(10, "baz")]),
+        ([{"internal_version": 10, "version": "baz"}], ["baz"]),
         (
             [
                 {"internal_version": 10, "version": "baz"},
                 {"internal_version": 20, "version": "bar"},
             ],
-            [(10, "baz"), (20, "bar")],
+            ["baz", "bar"],
         ),
         ([], []),
     ],
